@@ -15,7 +15,7 @@ from ._internal_init import *
 
 __all__ = [
     'AsdfFile', 'CustomType', 'AsdfExtension', 'Stream', 'open', 'test',
-    'commands', 'ExternalArrayReference'
+    'commands', 'IntegerType', 'ExternalArrayReference'
 ]
 
 try:
@@ -33,25 +33,16 @@ try:
 except ImportError:
     raise ImportError("asdf requires numpy")
 
-from .asdf import AsdfFile
-from .asdftypes import CustomType
+from .asdf import AsdfFile, open_asdf
+from .types import CustomType
 from .extension import AsdfExtension
 from .stream import Stream
 from . import commands
+from .tags.core import IntegerType
 from .tags.core.external_reference import ExternalArrayReference
 
 from jsonschema import ValidationError
 
-# TODO: there doesn't seem to be any reason to redefine this here
-class ValidationError(ValidationError):
-    pass
-
-try:
-    from astropy.io import fits
-except ImportError:
-    pass
-else:
-    from .fits_embed import _AsdfHDU
-    fits.register_hdu(_AsdfHDU)
-
-open = AsdfFile.open
+open = open_asdf
+# Avoid redundancy/confusion in the top-level namespace
+del open_asdf
