@@ -12,6 +12,7 @@ from collections import namedtuple
 from urllib import parse as urlparse
 
 import numpy as np
+from numpy.ma.core import masked_array
 
 import yaml
 
@@ -25,11 +26,12 @@ from . import util
 from . import yamlutil
 
 
-class BlockManager(object):
+class BlockManager:
     """
     Manages the `Block`s associated with a ASDF file.
     """
-    def __init__(self, asdffile, copy_arrays=False):
+    def __init__(self, asdffile, copy_arrays=False, lazy_load=True,
+                 readonly=False):
         self._asdffile = weakref.ref(asdffile)
 
         self._internal_blocks = []
@@ -47,6 +49,8 @@ class BlockManager(object):
         self._data_to_block_mapping = {}
         self._validate_checksums = False
         self._memmap = not copy_arrays
+        self._lazy_load = lazy_load
+        self._readonly = readonly
 
     def __len__(self):
         """
@@ -182,6 +186,21 @@ class BlockManager(object):
         for block in self._inline_blocks:
             yield block
 
+    @property
+    def memmap(self):
+        """
+        The flag which indicates whether the arrays are memory mapped
+        to the underlying file.
+        """
+        return self._memmap
+
+    @property
+    def lazy_load(self):
+        """
+        The flag which indicates whether the blocks are lazily read.
+        """
+        return self._lazy_load
+
     def has_blocks_with_offset(self):
         """
         Returns `True` if any of the internal blocks currently have an
@@ -192,6 +211,9 @@ class BlockManager(object):
                 return True
         return False
 
+    def _new_block(self):
+        return Block(memmap=self.memmap, lazy_load=self.lazy_load)
+
     def _sort_blocks_by_offset(self):
         def sorter(x):
             if x.offset is None:
@@ -203,7 +225,7 @@ class BlockManager(object):
     def _read_next_internal_block(self, fd, past_magic=False):
         # This assumes the file pointer is at the beginning of the
         # block, (or beginning + 4 if past_magic is True)
-        block = Block(memmap=self._memmap).read(
+        block = self._new_block().read(
             fd, past_magic=past_magic,
             validate_checksum=self._validate_checksums)
         if block is not None:
@@ -253,22 +275,23 @@ class BlockManager(object):
         This is called before updating a file, since updating requires
         knowledge of all internal blocks in the file.
         """
-        if len(self._internal_blocks):
-            for i, block in enumerate(self._internal_blocks):
-                if isinstance(block, UnloadedBlock):
-                    block.load()
+        if not self._internal_blocks:
+            return
+        for i, block in enumerate(self._internal_blocks):
+            if isinstance(block, UnloadedBlock):
+                block.load()
 
-            last_block = self._internal_blocks[-1]
+        last_block = self._internal_blocks[-1]
 
-            # Read all of the remaining blocks in the file, if any
-            if (last_block._fd is not None and
-                last_block._fd.seekable()):
-                last_block._fd.seek(last_block.end_offset)
-                while True:
-                    last_block = self._read_next_internal_block(
-                        last_block._fd, False)
-                    if last_block is None:
-                        break
+        # Read all of the remaining blocks in the file, if any
+        if (last_block._fd is not None and
+            last_block._fd.seekable()):
+            last_block._fd.seek(last_block.end_offset)
+            while True:
+                last_block = self._read_next_internal_block(
+                    last_block._fd, False)
+                if last_block is None:
+                    break
 
     def write_internal_blocks_serial(self, fd, pad_blocks=False):
         """
@@ -490,7 +513,7 @@ class BlockManager(object):
         # make sure it makes sense.
         fd.seek(offsets[-1], generic_io.SEEK_SET)
         try:
-            block = Block(memmap=self._memmap).read(fd)
+            block = self._new_block().read(fd)
         except (ValueError, IOError):
             return
 
@@ -502,11 +525,17 @@ class BlockManager(object):
         # objects
         for offset in offsets[1:-1]:
             self._internal_blocks.append(
-                UnloadedBlock(fd, offset, memmap=self._memmap))
+                UnloadedBlock(fd, offset,
+                              memmap=self.memmap, lazy_load=self.lazy_load,
+                              readonly=self._readonly))
 
         # We already read the last block in the file -- no need to read it again
         self._internal_blocks.append(block)
 
+        # Materialize the internal blocks if we are not lazy
+        if not self.lazy_load:
+            self.finish_reading_internal_blocks()
+
     def get_external_filename(self, filename, index):
         """
         Given a main filename and an index number, return a new file
@@ -687,6 +716,20 @@ class BlockManager(object):
 
         raise ValueError("block not found.")
 
+    def _should_inline(self, array):
+
+        if not np.issubdtype(array.dtype, np.number):
+            return False
+
+        if isinstance(array, masked_array):
+            return False
+
+        # Make sure none of the values are too large to store as literals
+        if (array[~np.isnan(array)] > 2**52).any():
+            return False
+
+        return array.size <= self._inline_threshold_size
+
     def find_or_create_block_for_array(self, arr, ctx):
         """
         For a given array, looks for an existing block containing its
@@ -746,7 +789,7 @@ class BlockManager(object):
             block.close()
 
 
-class Block(object):
+class Block:
     """
     Represents a single block in a ASDF file.  This is an
     implementation detail and should not be instantiated directly.
@@ -762,9 +805,13 @@ class Block(object):
         ('checksum', '16s')
     ])
 
-    def __init__(self, data=None, uri=None, array_storage='internal', memmap=True):
+    def __init__(self, data=None, uri=None, array_storage='internal',
+                 memmap=True, lazy_load=True):
         if isinstance(data, np.ndarray) and not data.flags.c_contiguous:
-            self._data = np.ascontiguousarray(data)
+            if data.flags.f_contiguous:
+                self._data = np.asfortranarray(data)
+            else:
+                self._data = np.ascontiguousarray(data)
         else:
             self._data = data
         self._uri = uri
@@ -777,6 +824,8 @@ class Block(object):
         self._checksum = None
         self._should_memmap = memmap
         self._memmapped = False
+        self._lazy_load = lazy_load
+        self._readonly = False
 
         self.update_size()
         self._allocated = self._size
@@ -859,6 +908,10 @@ class Block(object):
     def checksum(self):
         return self._checksum
 
+    @property
+    def readonly(self):
+        return self._readonly
+
     def _set_checksum(self, checksum):
         if checksum == b'\0' * 16:
             self._checksum = None
@@ -867,7 +920,7 @@ class Block(object):
 
     def _calculate_checksum(self, data):
         m = hashlib.new('md5')
-        m.update(self.data)
+        m.update(self.data.flatten())
         return m.digest()
 
     def validate_checksum(self):
@@ -914,10 +967,10 @@ class Block(object):
         """
         Read a Block from the given Python file-like object.
 
-        If the file is seekable, the reading or memmapping of the
-        actual data is postponed until an array requests it.  If the
-        file is a stream, the data will be read into memory
-        immediately.
+        If the file is seekable and lazy_load is True, the reading
+        or memmapping of the actual data is postponed until an array
+        requests it.  If the file is a stream or lazy_load is False,
+        the data will be read into memory immediately.
 
         Parameters
         ----------
@@ -983,19 +1036,33 @@ class Block(object):
             # If the file is seekable, we can delay reading the actual
             # data until later.
             self._fd = fd
-            self._header_size = header_size
             self._offset = offset
+            self._header_size = header_size
             if header['flags'] & constants.BLOCK_FLAG_STREAMED:
                 # Support streaming blocks
-                fd.fast_forward(-1)
                 self._array_storage = 'streamed'
-                self._data_size = self._size = self._allocated = \
-                    (fd.tell() - self.data_offset) + 1
+                if self._lazy_load:
+                    fd.fast_forward(-1)
+                    self._data_size = self._size = self._allocated = \
+                        (fd.tell() - self.data_offset) + 1
+                else:
+                    self._data = fd.read_into_array(-1)
+                    self._data_size = self._size = self._allocated = len(self._data)
             else:
-                fd.fast_forward(header['allocated_size'])
                 self._allocated = header['allocated_size']
                 self._size = header['used_size']
                 self._data_size = header['data_size']
+                if self._lazy_load:
+                    fd.fast_forward(self._allocated)
+                else:
+                    curpos = fd.tell()
+                    self._memmap_data()
+                    fd.seek(curpos)
+                    if not self._memmapped:
+                        self._data = self._read_data(fd, self._size, self._data_size)
+                        fd.fast_forward(self._allocated - self._size)
+                    else:
+                        fd.fast_forward(self._allocated)
         else:
             # If the file is a stream, we need to get the data now.
             if header['flags'] & constants.BLOCK_FLAG_STREAMED:
@@ -1004,9 +1071,9 @@ class Block(object):
                 self._data = fd.read_into_array(-1)
                 self._data_size = self._size = self._allocated = len(self._data)
             else:
-                self._data_size = header['data_size']
-                self._size = header['used_size']
                 self._allocated = header['allocated_size']
+                self._size = header['used_size']
+                self._data_size = header['data_size']
                 self._data = self._read_data(fd, self._size, self._data_size)
                 fd.fast_forward(self._allocated - self._size)
             fd.close()
@@ -1019,12 +1086,24 @@ class Block(object):
         return self
 
     def _read_data(self, fd, used_size, data_size):
+        """
+        Read the block data from a file.
+        """
         if not self.input_compression:
             return fd.read_into_array(used_size)
         else:
             return mcompression.decompress(
                 fd, used_size, data_size, self.input_compression)
 
+    def _memmap_data(self):
+        """
+        Memory map the block data from the file.
+        """
+        memmap = self._fd.can_memmap() and not self.input_compression
+        if self._should_memmap and memmap:
+            self._data = self._fd.memmap_array(self.data_offset, self._size)
+            self._memmapped = True
+
     def write(self, fd):
         """
         Write an internal block to the given Python file-like object.
@@ -1101,12 +1180,8 @@ class Block(object):
             # Be nice and reset the file position after we're done
             curpos = self._fd.tell()
             try:
-                memmap = self._fd.can_memmap() and not self.input_compression
-                if self._should_memmap and memmap:
-                    self._data = self._fd.memmap_array(
-                        self.data_offset, self._size)
-                    self._memmapped = True
-                else:
+                self._memmap_data()
+                if not self._memmapped:
                     self._fd.seek(self.data_offset)
                     self._data = self._read_data(
                         self._fd, self._size, self._data_size)
@@ -1126,17 +1201,17 @@ class Block(object):
                 self._data.flush()
             if self._data._mmap is not None:
                 self._data._mmap.close()
-            self._data = None
+        self._data = None
 
 
-class UnloadedBlock(object):
+class UnloadedBlock:
     """
     Represents an indexed, but not yet loaded, internal block.  All
     that is known about it is its offset.  It converts itself to a
     full-fledged block whenever the underlying data or more detail is
     requested.
     """
-    def __init__(self, fd, offset, memmap=True):
+    def __init__(self, fd, offset, memmap=True, lazy_load=True, readonly=False):
         self._fd = fd
         self._offset = offset
         self._data = None
@@ -1147,6 +1222,8 @@ class UnloadedBlock(object):
         self._checksum = None
         self._should_memmap = memmap
         self._memmapped = False
+        self._lazy_load = lazy_load
+        self._readonly = readonly
 
     def __len__(self):
         self.load()
