@@ -28,6 +28,7 @@ except ImportError:
         GREEN = ''
         RESET = ''
 
+import asdf
 from .main import Command
 from .. import AsdfFile
 from .. import treeutil
@@ -69,7 +70,7 @@ class Diff(Command): # pragma: no cover
     def run(cls, args):
         return diff(args.filenames, args.minimal)
 
-class ArrayNode(object):
+class ArrayNode:
     """This class is used to represent unique dummy nodes in the diff tree. In
     general these dummy nodes will be list elements that we want to keep track
     of but not necessarily display. This allows the diff output to be
@@ -80,7 +81,7 @@ class ArrayNode(object):
     def __hash__(self):
         return hash(self.name)
 
-class PrintTree(object):
+class PrintTree:
     """This class is used to remember the nodes in the tree that have already
     been displayed in the diff output.
     """
@@ -113,7 +114,7 @@ class PrintTree(object):
                 current['children'][node] = dict(visited=True, children=dict())
             current = current['children'][node]
 
-class DiffContext(object):
+class DiffContext:
     """Class that contains context data of the diff to be computed"""
     def __init__(self, asdf0, asdf1, iostream, minimal=False):
         self.asdf0 = asdf0
@@ -245,8 +246,8 @@ def compare_trees(diff_ctx, tree0, tree1, keys=[]):
 def diff(filenames, minimal, iostream=sys.stdout):
     """Top-level implementation of diff algorithm"""
     try:
-        with AsdfFile.open(filenames[0], _force_raw_types=True) as asdf0:
-            with AsdfFile.open(filenames[1], _force_raw_types=True) as asdf1:
+        with asdf.open(filenames[0], _force_raw_types=True) as asdf0:
+            with asdf.open(filenames[1], _force_raw_types=True) as asdf1:
                 diff_ctx = DiffContext(asdf0, asdf1, iostream, minimal=minimal)
                 compare_trees(diff_ctx, asdf0.tree, asdf1.tree)
     except ValueError as error:
