@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
 
-from __future__ import absolute_import, division, unicode_literals, print_function
 
 import numpy as np
 
@@ -23,6 +22,7 @@ YAML_END_MARKER_REGEX = br'\r?\n\.\.\.((\r?\n)|$)'
 
 
 STSCI_SCHEMA_URI_BASE = 'http://stsci.edu/schemas/'
+STSCI_SCHEMA_TAG_BASE = 'tag:stsci.edu:asdf'
 
 
 BLOCK_FLAG_STREAMED = 0x1
