@@ -137,6 +137,7 @@ class AsdfExtensionList:
                     validators.update(sibling.validators)
         self._tag_mapping = resolver.Resolver(tag_mapping, 'tag')
         self._url_mapping = resolver.Resolver(url_mapping, 'url')
+        self._resolver = resolver.ResolverChain(self._tag_mapping, self._url_mapping)
         self._validators = validators
 
     @property
@@ -156,6 +157,10 @@ class AsdfExtensionList:
     def url_mapping(self):
         return self._url_mapping
 
+    @property
+    def resolver(self):
+        return self._resolver
+
     @property
     def type_index(self):
         return self._type_index
@@ -244,4 +249,16 @@ class _DefaultExtensions:
         self._extension_list = None
         self._package_metadata = {}
 
+    @property
+    def resolver(self):
+        return self.extension_list.resolver
+
+
 default_extensions = _DefaultExtensions()
+
+
+def get_default_resolver():
+    """
+    Get the resolver that includes mappings from all installed extensions.
+    """
+    return default_extensions.resolver
