@@ -5,6 +5,7 @@ import os
 import json
 import datetime
 import warnings
+import copy
 from numbers import Integral
 from functools import lru_cache
 from collections import OrderedDict
@@ -22,6 +23,9 @@ from . import reference
 from . import treeutil
 from . import util
 from .extension import default_extensions
+from .compat.jsonschemacompat import JSONSCHEMA_LT_3
+from . import extension
+from .exceptions import AsdfDeprecationWarning
 
 
 YAML_SCHEMA_METASCHEMA_ID = 'http://stsci.edu/schemas/yaml-schema/draft-01'
@@ -40,9 +44,13 @@ def default_ext_resolver(uri):
     """
     Resolver that uses tag/url mappings from all installed extensions
     """
-    tag_mapping = default_extensions.extension_list.tag_mapping
-    url_mapping = default_extensions.extension_list.url_mapping
-    return url_mapping(tag_mapping(uri))
+    # Deprecating this because it doesn't play nicely with the caching on
+    # load_schema(...).
+    warnings.warn(
+            "The 'default_ext_resolver(...)' function is deprecated. Use "
+            "'asdf.extension.get_default_resolver()(...)' instead.",
+            AsdfDeprecationWarning)
+    return extension.get_default_resolver()(uri)
 
 
 PYTHON_TYPE_TO_YAML_TAG = {
@@ -72,6 +80,7 @@ def _type_to_tag(type_):
 
 
 def validate_tag(validator, tagname, instance, schema):
+
     if hasattr(instance, '_tag'):
         instance_tag = instance._tag
     else:
@@ -197,15 +206,29 @@ for key in ('allOf', 'anyOf', 'oneOf', 'items'):
 REMOVE_DEFAULTS['properties'] = validate_remove_default
 
 
-
 @lru_cache()
 def _create_validator(validators=YAML_VALIDATORS):
-    meta_schema = load_schema(YAML_SCHEMA_METASCHEMA_ID, default_ext_resolver)
-    base_cls = mvalidators.create(meta_schema=meta_schema, validators=validators)
+    meta_schema = load_schema(YAML_SCHEMA_METASCHEMA_ID, extension.get_default_resolver())
+
+    if JSONSCHEMA_LT_3:
+        base_cls = mvalidators.create(meta_schema=meta_schema, validators=validators)
+    else:
+        type_checker = mvalidators.Draft4Validator.TYPE_CHECKER.redefine(
+            'array',
+            lambda checker, instance: isinstance(instance, list) or isinstance(instance, tuple)
+        )
+        id_of = mvalidators.Draft4Validator.ID_OF
+        base_cls = mvalidators.create(
+            meta_schema=meta_schema,
+            validators=validators,
+            type_checker=type_checker,
+            id_of=id_of
+        )
 
     class ASDFValidator(base_cls):
-        DEFAULT_TYPES = base_cls.DEFAULT_TYPES.copy()
-        DEFAULT_TYPES['array'] = (list, tuple)
+        if JSONSCHEMA_LT_3:
+            DEFAULT_TYPES = base_cls.DEFAULT_TYPES.copy()
+            DEFAULT_TYPES['array'] = (list, tuple)
 
         def iter_errors(self, instance, _schema=None, _seen=set()):
             # We can't validate anything that looks like an external reference,
@@ -341,7 +364,7 @@ def load_custom_schema(url):
 
     return update(custom, core)
 
-@lru_cache()
+
 def load_schema(url, resolver=None, resolve_references=False,
                 resolve_local_refs=False):
     """
@@ -368,7 +391,20 @@ def load_schema(url, resolver=None, resolve_references=False,
         control local reference resolution separately.
     """
     if resolver is None:
-        resolver = default_ext_resolver
+        # We can't just set this as the default in load_schema's definition
+        # because invoking get_default_resolver at import time leads to a circular import.
+        resolver = extension.get_default_resolver()
+
+    # We want to cache the work that went into constructing the schema, but returning
+    # the same object is treacherous, because users who mutate the result will not
+    # expect that they're changing the schema everywhere.
+    return copy.deepcopy(
+        _load_schema_cached(url, resolver, resolve_references, resolve_local_refs)
+    )
+
+
+@lru_cache()
+def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
     loader = _make_schema_loader(resolver)
     if url in HARDCODED_SCHEMA:
         schema = HARDCODED_SCHEMA[url]()
@@ -592,9 +628,9 @@ def check_schema(schema):
     })
 
     meta_schema_id = schema.get('$schema', YAML_SCHEMA_METASCHEMA_ID)
-    meta_schema = load_schema(meta_schema_id, default_ext_resolver)
+    meta_schema = load_schema(meta_schema_id, extension.get_default_resolver())
 
-    resolver = _make_resolver(default_ext_resolver)
+    resolver = _make_resolver(extension.get_default_resolver())
 
     cls = mvalidators.create(meta_schema=meta_schema,
                              validators=VALIDATORS)
