@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import sys
+import weakref
 
 import numpy as np
 from numpy import ma
@@ -221,6 +222,7 @@ class NDArrayType(AsdfType):
         self._asdffile = asdffile
         self._source = source
         self._block = None
+        self._block_data_weakref = None
         self._array = None
         self._mask = mask
 
@@ -244,6 +246,17 @@ class NDArrayType(AsdfType):
             self._make_array()
 
     def _make_array(self):
+        # If the ASDF file has been updated in-place, then there's
+        # a chance that the block's original data object has been
+        # closed and replaced.  We need to check here and re-generate
+        # the array if necessary, otherwise we risk segfaults when
+        # memory mapping.
+        if self._block_data_weakref is not None:
+            block_data = self._block_data_weakref()
+            if block_data is not self.block.data:
+                self._array = None
+                self._block_data_weakref = None
+
         if self._array is None:
             block = self.block
             shape = self.get_actual_shape(
@@ -251,6 +264,7 @@ class NDArrayType(AsdfType):
             self._array = np.ndarray(
                 shape, self._dtype, block.data,
                 self._offset, self._strides, self._order)
+            self._block_data_weakref = weakref.ref(block.data)
             self._array = self._apply_mask(self._array, self._mask)
             if block.readonly:
                 self._array.setflags(write=False)
@@ -331,7 +345,6 @@ class NDArrayType(AsdfType):
         else:
             return self._array.dtype
 
-    @property
     def __len__(self):
         if self._array is None:
             return self._shape[0]
@@ -354,6 +367,7 @@ class NDArrayType(AsdfType):
             self._make_array().__setitem__(*args)
         except Exception as e:
             self._array = None
+            self._block_data_weakref = None
             raise e from None
 
     @classmethod
