@@ -322,6 +322,17 @@ def test_mask_roundtrip(tmpdir):
 
     helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_asdf)
 
+def test_len_roundtrip(tmpdir):
+    sequence = np.arange(0, 10, dtype=np.int)
+    tree = {
+        'sequence': sequence
+        }
+
+    def check_len(asdf):
+        s = asdf.tree["sequence"]
+        assert len(s) == 10
+
+    helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_len)
 
 def test_mask_arbitrary():
     content = """
@@ -847,7 +858,6 @@ def test_readonly(tmpdir):
 
 
 def test_readonly_inline(tmpdir):
-
     tmpfile = str(tmpdir.join('data.asdf'))
     tree = dict(data=np.ndarray((100)))
 
@@ -858,3 +868,18 @@ def test_readonly_inline(tmpdir):
     with asdf.open(tmpfile, mode='r') as af:
         assert af['data'].flags.writeable == True
         af['data'][0] = 42
+
+
+# Confirm that NDArrayType's internal array is regenerated
+# following an update.
+def test_block_data_change(tmpdir):
+    tmpfile = str(tmpdir.join("data.asdf"))
+    tree = {"data": np.ndarray(10)}
+    with asdf.AsdfFile(tree) as af:
+        af.write_to(tmpfile)
+
+    with asdf.open(tmpfile, mode="rw") as af:
+        array_before = af.tree["data"].__array__()
+        af.update()
+        array_after = af.tree["data"].__array__()
+        assert array_before is not array_after
