@@ -57,6 +57,8 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat):
     hdulist = fits.HDUList()
     hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float), name='SCI'))
     hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float), name='DQ'))
+    # Test a name with underscores to make sure it works
+    hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float), name='WITH_UNDERSCORE'))
 
     tree = {
         'model': {
@@ -67,6 +69,10 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat):
             'dq': {
                 'data': hdulist['DQ'].data,
                 'wcs': 'WCS info'
+            },
+            'with_underscore': {
+                'data': hdulist['WITH_UNDERSCORE'].data,
+                'wcs': 'WCS info'
             }
         }
     }
@@ -75,8 +81,8 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat):
     ff.write_to(fits_testfile, use_image_hdu=backwards_compat)
 
     with fits.open(fits_testfile) as hdulist2:
-        assert len(hdulist2) == 3
-        assert [x.name for x in hdulist2] == ['SCI', 'DQ', 'ASDF']
+        assert len(hdulist2) == 4
+        assert [x.name for x in hdulist2] == ['SCI', 'DQ', 'WITH_UNDERSCORE', 'ASDF']
         assert_array_equal(hdulist2[0].data, np.arange(512, dtype=np.float))
         asdf_hdu = hdulist2['ASDF']
         assert asdf_hdu.data.tostring().startswith(b'#ASDF')
@@ -86,7 +92,7 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat):
             assert isinstance(asdf_hdu, fits.ImageHDU)
             assert asdf_hdu.data.tostring().strip().endswith(b'...')
         else:
-            assert isinstance(asdf_hdu, fits_embed._AsdfHDU)
+            assert isinstance(asdf_hdu, fits.BinTableHDU)
 
         with fits_embed.AsdfInFits.open(hdulist2) as ff2:
             assert_tree_match(tree, ff2.tree)
@@ -94,7 +100,7 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat):
             ff = asdf.AsdfFile(copy.deepcopy(ff2.tree))
             ff.write_to(asdf_testfile)
 
-    with asdf.AsdfFile.open(asdf_testfile) as ff:
+    with asdf.open(asdf_testfile) as ff:
         assert_tree_match(tree, ff.tree)
 
 
@@ -110,7 +116,7 @@ def test_embed_asdf_in_fits_file_anonymous_extensions(tmpdir):
         assert len(hdulist) == 4
         assert [x.name for x in hdulist] == ['PRIMARY', '', '', 'ASDF']
         asdf_hdu = hdulist['ASDF']
-        assert isinstance(asdf_hdu, fits_embed._AsdfHDU)
+        assert isinstance(asdf_hdu, fits.BinTableHDU)
         assert asdf_hdu.data.tostring().startswith(b'#ASDF')
 
         with fits_embed.AsdfInFits.open(hdulist) as ff2:
@@ -119,7 +125,7 @@ def test_embed_asdf_in_fits_file_anonymous_extensions(tmpdir):
             ff = asdf.AsdfFile(copy.deepcopy(ff2.tree))
             ff.write_to(os.path.join(str(tmpdir), 'test.asdf'))
 
-    with asdf.AsdfFile.open(os.path.join(str(tmpdir), 'test.asdf')) as ff:
+    with asdf.open(os.path.join(str(tmpdir), 'test.asdf')) as ff:
         assert_tree_match(asdf_in_fits.tree, ff.tree)
 
 
@@ -207,12 +213,12 @@ def test_create_in_tree_first(tmpdir):
     with asdf.AsdfFile(tree) as ff:
         ff.write_to(os.path.join(str(tmpdir), 'plain.asdf'))
 
-    with asdf.AsdfFile.open(os.path.join(str(tmpdir), 'plain.asdf')) as ff:
+    with asdf.open(os.path.join(str(tmpdir), 'plain.asdf')) as ff:
         assert_array_equal(ff.tree['model']['sci']['data'],
                            np.arange(512, dtype=np.float))
 
     # This tests the changes that allow FITS files with ASDF extensions to be
-    # opened directly by the top-level AsdfFile.open API
+    # opened directly by the top-level asdf.open API
     with asdf_open(tmpfile) as ff:
         assert_array_equal(ff.tree['model']['sci']['data'],
                            np.arange(512, dtype=np.float))
@@ -283,13 +289,13 @@ def test_open_gzipped():
 
     # Opening as an HDU should work
     with fits.open(testfile) as ff:
-        with asdf.AsdfFile.open(ff) as af:
+        with asdf.open(ff) as af:
             assert af.tree['stuff'].shape == (20, 20)
 
     with fits_embed.AsdfInFits.open(testfile) as af:
         assert af.tree['stuff'].shape == (20, 20)
 
-    with asdf.AsdfFile.open(testfile) as af:
+    with asdf.open(testfile) as af:
         assert af.tree['stuff'].shape == (20, 20)
 
 def test_bad_input(tmpdir):
@@ -305,21 +311,22 @@ def test_bad_input(tmpdir):
 @pytest.mark.skipif(sys.platform.startswith('win'),
     reason='Avoid path manipulation on Windows')
 def test_version_mismatch_file():
+
     testfile = str(get_test_data_path('version_mismatch.fits'))
 
     with pytest.warns(None) as w:
-        with asdf.AsdfFile.open(testfile,
+        with asdf.open(testfile,
                 ignore_version_mismatch=False) as fits_handle:
             assert fits_handle.tree['a'] == complex(0j)
     # This is the warning that we expect from opening the FITS file
-    assert len(w) == 1
+    assert len(w) == 1, display_warnings(w)
     assert str(w[0].message) == (
         "'tag:stsci.edu:asdf/core/complex' with version 7.0.0 found in file "
         "'{}', but latest supported version is 1.0.0".format(testfile))
 
     # Make sure warning does not occur when warning is ignored (default)
     with pytest.warns(None) as w:
-        with asdf.AsdfFile.open(testfile) as fits_handle:
+        with asdf.open(testfile) as fits_handle:
             assert fits_handle.tree['a'] == complex(0j)
     assert len(w) == 0, display_warnings(w)
 
@@ -352,7 +359,7 @@ def test_serialize_table(tmpdir):
     with fits_embed.AsdfInFits(hdulist, tree) as ff:
         ff.write_to(tmpfile)
 
-    with asdf.AsdfFile.open(tmpfile) as ff:
+    with asdf.open(tmpfile) as ff:
         data = ff.tree['my_table']
         assert data._source.startswith('fits:')
 
@@ -360,7 +367,7 @@ def test_extension_check():
     testfile = get_test_data_path('extension_check.fits')
 
     with pytest.warns(None) as warnings:
-        with asdf.AsdfFile.open(testfile) as ff:
+        with asdf.open(testfile) as ff:
             pass
 
     assert len(warnings) == 1, display_warnings(warnings)
@@ -369,11 +376,54 @@ def test_extension_check():
 
     # Make sure that suppressing the warning works as well
     with pytest.warns(None) as warnings:
-        with asdf.AsdfFile.open(testfile, ignore_missing_extensions=True) as ff:
+        with asdf.open(testfile, ignore_missing_extensions=True) as ff:
             pass
 
     assert len(warnings) == 0, display_warnings(warnings)
 
     with pytest.raises(RuntimeError):
-        with asdf.AsdfFile.open(testfile, strict_extension_check=True) as ff:
+        with asdf.open(testfile, strict_extension_check=True) as ff:
             pass
+
+def test_verify_with_astropy(tmpdir):
+    tmpfile = str(tmpdir.join('asdf.fits'))
+
+    with create_asdf_in_fits() as aif:
+        aif.write_to(tmpfile)
+
+    with fits.open(tmpfile) as hdu:
+        hdu.verify('exception')
+
+def test_dangling_file_handle(tmpdir):
+    """
+    This tests the bug fix introduced in #533. Without the bug fix, this test
+    will fail when running the test suite with pytest-openfiles.
+    """
+    import gc
+
+    fits_filename = str(tmpdir.join('dangling.fits'))
+
+    # Create FITS file to use for test
+    hdulist = fits.HDUList()
+    hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float)))
+    hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float)))
+    hdulist.append(fits.ImageHDU(np.arange(512, dtype=np.float)))
+    hdulist.writeto(fits_filename)
+    hdulist.close()
+
+    hdul = fits.open(fits_filename)
+    gc.collect()
+
+    ctx = asdf.AsdfFile()
+    gc.collect()
+
+    ctx.blocks.find_or_create_block_for_array(hdul[0].data, ctx)
+    gc.collect()
+
+    hdul.close()
+    gc.collect()
+
+    ctx.close()
+    gc.collect()
+
+    del ctx
