@@ -16,18 +16,22 @@ from asdf import util
 from asdf import generic_io
 from asdf.asdf import is_asdf_file
 
-from . import helpers
-# The only reason for importing these is to use them in the fixture below
-from .conftest import small_tree, large_tree
+from . import helpers, create_small_tree, create_large_tree
 
 
-@pytest.fixture(params=[small_tree, large_tree])
+@pytest.fixture(params=[create_small_tree, create_large_tree])
 def tree(request):
     return request.param()
 
 
 def _roundtrip(tree, get_write_fd, get_read_fd,
                write_options={}, read_options={}):
+
+    # Since we're testing with small arrays, force all arrays to be stored
+    # in internal blocks rather than letting some of them be automatically put
+    # inline.
+    write_options.setdefault('all_array_storage', 'internal')
+
     with get_write_fd() as fd:
         asdf.AsdfFile(tree).write_to(fd, **write_options)
         # Work around the fact that generic_io's get_file doesn't have a way of
@@ -37,7 +41,7 @@ def _roundtrip(tree, get_write_fd, get_read_fd,
             fd._fd.close()
 
     with get_read_fd() as fd:
-        ff = asdf.AsdfFile.open(fd, **read_options)
+        ff = asdf.open(fd, **read_options)
         helpers.assert_tree_match(tree, ff.tree)
 
     return ff
@@ -72,7 +76,8 @@ def test_path(tree, tmpdir):
         return f
 
     def get_read_fd():
-        f = generic_io.get_file(path, mode='r')
+        # Must open with mode=rw in order to get memmapped data
+        f = generic_io.get_file(path, mode='rw')
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
         # This is to check for a "feature" in Python 3.x that reading zero
@@ -91,17 +96,16 @@ def test_open2(tree, tmpdir):
     path = os.path.join(str(tmpdir), 'test.asdf')
 
     def get_write_fd():
-        f = generic_io.get_file(open(path, 'wb'), mode='w')
+        f = generic_io.get_file(open(path, 'wb'), mode='w', close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
-        f._close = True
         return f
 
     def get_read_fd():
-        f = generic_io.get_file(open(path, 'rb'), mode='r')
+        # Must open with mode=rw in order to get memmapped data
+        f = generic_io.get_file(open(path, 'r+b'), mode='rw', close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
-        f._close = True
         return f
 
     with _roundtrip(tree, get_write_fd, get_read_fd) as ff:
@@ -151,17 +155,15 @@ def test_io_open(tree, tmpdir):
     path = os.path.join(str(tmpdir), 'test.asdf')
 
     def get_write_fd():
-        f = generic_io.get_file(io.open(path, 'wb'), mode='w')
+        f = generic_io.get_file(io.open(path, 'wb'), mode='w', close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
-        f._close = True
         return f
 
     def get_read_fd():
-        f = generic_io.get_file(io.open(path, 'r+b'), mode='rw')
+        f = generic_io.get_file(io.open(path, 'r+b'), mode='rw', close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
-        f._close = True
         return f
 
     with _roundtrip(tree, get_write_fd, get_read_fd) as ff:
@@ -170,6 +172,22 @@ def test_io_open(tree, tmpdir):
         ff.tree['science_data'][0] = 42
 
 
+def test_close_underlying(tmpdir):
+    path = os.path.join(str(tmpdir), 'test.asdf')
+
+    with generic_io.get_file(open(path, 'wb'), mode='w', close=True) as ff:
+        pass
+
+    assert ff.is_closed() == True
+    assert ff._fd.closed == True
+
+    with generic_io.get_file(open(path, 'rb'), close=True) as ff2:
+        pass
+
+    assert ff2.is_closed() == True
+    assert ff2._fd.closed == True
+
+
 def test_bytes_io(tree):
     buff = io.BytesIO()
 
@@ -324,7 +342,7 @@ def test_exploded_filesystem_fail(tree, tmpdir):
         asdf.AsdfFile(tree).write_to(fd, all_array_storage='external')
 
     with get_read_fd() as fd:
-        with asdf.AsdfFile.open(fd) as ff:
+        with asdf.open(fd) as ff:
             with pytest.raises(ValueError):
                 helpers.assert_tree_match(tree, ff.tree)
 
@@ -370,7 +388,7 @@ def test_exploded_stream_read(tmpdir, small_tree):
     with open(path, 'rb') as fd:
         # This should work, so we can get the tree content
         x = generic_io.InputStream(fd, 'r')
-        with asdf.AsdfFile.open(x) as ff:
+        with asdf.open(x) as ff:
             # It's only when trying to access external data that an error occurs
             with pytest.raises(ValueError):
                 ff.tree['science_data'][:]
@@ -385,7 +403,7 @@ def test_unicode_open(tmpdir, small_tree):
 
     with io.open(path, 'rt', encoding="utf-8") as fd:
         with pytest.raises(ValueError):
-            with asdf.AsdfFile.open(fd):
+            with asdf.open(fd):
                 pass
 
 
@@ -447,11 +465,11 @@ def test_relative_uri():
 
 
 def test_arbitrary_file_object():
-    class Wrapper(object):
+    class Wrapper:
         def __init__(self, init):
             self._fd = init
 
-    class Random(object):
+    class Random:
         def seek(self, *args):
             return self._fd.seek(*args)
 
