@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 import io
-from collections import OrderedDict
+from collections import namedtuple, OrderedDict
+from typing import NamedTuple
 
 import numpy as np
 
@@ -77,7 +78,7 @@ def test_arbitrary_python_object():
     # Putting "just any old" Python object in the tree should raise an
     # exception.
 
-    class Foo(object):
+    class Foo:
         pass
 
     tree = {'object': Foo()}
@@ -88,6 +89,21 @@ def test_arbitrary_python_object():
         ff.write_to(buff)
 
 
+def run_tuple_test(tree, tmpdir):
+    def check_asdf(asdf):
+        assert isinstance(asdf.tree['val'], list)
+
+    def check_raw_yaml(content):
+        assert b'tuple' not in content
+
+    # Ignore these warnings for the tests that don't actually test the warning
+    init_options = dict(ignore_implicit_conversion=True)
+
+    helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_asdf,
+                                  raw_yaml_check_func=check_raw_yaml,
+                                  init_options=init_options)
+
+
 def test_python_tuple(tmpdir):
     # We don't want to store tuples as tuples, because that's not a
     # built-in YAML data type.  This test ensures that they are
@@ -97,14 +113,90 @@ def test_python_tuple(tmpdir):
         "val": (1, 2, 3)
     }
 
+    run_tuple_test(tree, tmpdir)
+
+
+def test_named_tuple_collections(tmpdir):
+    # Ensure that we are able to serialize a collections.namedtuple.
+
+    nt = namedtuple("TestNamedTuple1", ("one", "two", "three"))
+
+    tree = {
+        "val": nt(1, 2, 3)
+    }
+
+    run_tuple_test(tree, tmpdir)
+
+def test_named_tuple_typing(tmpdir):
+    # Ensure that we are able to serialize a typing.NamedTuple.
+
+    nt = NamedTuple("TestNamedTuple2",
+                    (("one", int), ("two", int), ("three", int)))
+    tree = {
+        "val": nt(1, 2, 3)
+    }
+
+    run_tuple_test(tree, tmpdir)
+
+
+def test_named_tuple_collections_recursive(tmpdir):
+    nt = namedtuple("TestNamedTuple3", ("one", "two", "three"))
+
+    tree = {
+        "val": nt(1, 2, np.ones(3))
+    }
+
     def check_asdf(asdf):
-        assert isinstance(asdf.tree['val'], list)
-
-    def check_raw_yaml(content):
-        assert b'tuple' not in content
+        assert (asdf.tree['val'][2] == np.ones(3)).all()
 
+    init_options = dict(ignore_implicit_conversion=True)
     helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_asdf,
-                                  raw_yaml_check_func=check_raw_yaml)
+                                  init_options=init_options)
+
+
+def test_named_tuple_typing_recursive(tmpdir):
+    nt = NamedTuple("TestNamedTuple4",
+                    (("one", int), ("two", int), ("three", np.ndarray)))
+
+    tree = {
+        "val": nt(1, 2, np.ones(3))
+    }
+
+    def check_asdf(asdf):
+        assert (asdf.tree['val'][2] == np.ones(3)).all()
+
+    init_options = dict(ignore_implicit_conversion=True)
+    helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_asdf,
+                                  init_options=init_options)
+
+
+def test_implicit_conversion_warning():
+    nt = namedtuple("TestTupleWarning", ("one", "two", "three"))
+
+    tree = {
+        "val": nt(1, 2, np.ones(3))
+    }
+
+    with pytest.warns(UserWarning, match="Failed to serialize instance"):
+        with asdf.AsdfFile(tree) as af:
+            pass
+
+    with pytest.warns(None) as w:
+        with asdf.AsdfFile(tree, ignore_implicit_conversion=True) as af:
+            assert len(w) == 0
+
+
+@pytest.mark.xfail(reason='pyyaml has a bug and does not support tuple keys')
+def test_python_tuple_key(tmpdir):
+    """
+    This tests whether tuple keys are round-tripped properly.
+
+    As of this writing, this does not work in pyyaml but does work in
+    ruamel.yaml. If/when we decide to switch to ruamel.yaml, this test should
+    pass.
+    """
+    tree = { (42, 1): 'foo' }
+    helpers.assert_roundtrip_tree(tree, tmpdir)
 
 
 def test_tags_removed_after_load(tmpdir):
@@ -131,7 +223,7 @@ foo: !<tag:stsci.edu:asdf/core/ndarray-1.0.0> [1, 2, 3]
     # Check that fully qualified explicit tags work
     buff = helpers.yaml_to_asdf(yaml, yaml_headers=False)
 
-    with asdf.AsdfFile.open(buff) as ff:
+    with asdf.open(buff) as ff:
         assert all(ff.tree['foo'] == [1, 2, 3])
 
 
@@ -170,14 +262,14 @@ def test_yaml_nan_inf():
     ff = asdf.AsdfFile(tree)
     ff.write_to(buff)
     buff.seek(0)
-    with asdf.AsdfFile.open(buff) as ff:
+    with asdf.open(buff) as ff:
         assert np.isnan(ff.tree['a'])
         assert np.isinf(ff.tree['b'])
         assert np.isinf(ff.tree['c'])
 
 
 def test_tag_object():
-    class SomeObject(object):
+    class SomeObject:
         pass
 
     tag = 'tag:nowhere.org:none/some/thing'
